import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { DataAnnotationDisplayMode_$type } from "./DataAnnotationDisplayMode";
import { IgxDataAnnotationRangeLayerComponent } from "./igx-data-annotation-range-layer-component";
import { IgxDataAnnotationShapeLayerComponent } from "./igx-data-annotation-shape-layer-component";
import { IgxDataAnnotationAxisLayerComponent } from "./igx-data-annotation-axis-layer-component";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { DataAnnotationStripLayer } from "./DataAnnotationStripLayer";
import { ensureEnum } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents an annotation layer that renders vertical or horizontal strips between values mapped to these properties:
 * StartValueMemberPath
 * EndValueMemberPath
*/
export let IgxDataAnnotationStripLayerComponent = /*@__PURE__*/ (() => {
    class IgxDataAnnotationStripLayerComponent extends IgxDataAnnotationRangeLayerComponent {
        constructor() {
            super();
        }
        createImplementation() {
            return new DataAnnotationStripLayer();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Gets or sets name of data column with positions for the start of annotations.
        */
        get startValueMemberPath() {
            return this.i.ag3;
        }
        set startValueMemberPath(v) {
            this.i.ag3 = v;
        }
        /**
         * Gets or sets mapping custom label at the start of annotations.
        */
        get startLabelMemberPath() {
            return this.i.ag0;
        }
        set startLabelMemberPath(v) {
            this.i.ag0 = v;
        }
        /**
         * Gets or sets display mode of label in the start annotation.
        */
        get startLabelDisplayMode() {
            return this.i.agc;
        }
        set startLabelDisplayMode(v) {
            this.i.agc = ensureEnum(DataAnnotationDisplayMode_$type, v);
        }
        /**
         * Gets or sets name of data column with positions for end of annotation.
        */
        get endValueMemberPath() {
            return this.i.agw;
        }
        set endValueMemberPath(v) {
            this.i.agw = v;
        }
        /**
         * Gets or sets mapping custom label at the end of annotations.
        */
        get endLabelMemberPath() {
            return this.i.agt;
        }
        set endLabelMemberPath(v) {
            this.i.agt = v;
        }
        /**
         * Gets or sets display mode of label at the end annotation.
        */
        get endLabelDisplayMode() {
            return this.i.agb;
        }
        set endLabelDisplayMode(v) {
            this.i.agb = ensureEnum(DataAnnotationDisplayMode_$type, v);
        }
        /**
         * Gets or sets mapping custom label between start and end of data annotations.
        */
        get centerLabelMemberPath() {
            return this.i.agp;
        }
        set centerLabelMemberPath(v) {
            this.i.agp = v;
        }
        /**
         * Gets or sets display mode of label in the center annotation.
        */
        get centerLabelDisplayMode() {
            return this.i.aga;
        }
        set centerLabelDisplayMode(v) {
            this.i.aga = ensureEnum(DataAnnotationDisplayMode_$type, v);
        }
    }
    IgxDataAnnotationStripLayerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxDataAnnotationStripLayerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxDataAnnotationStripLayerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxDataAnnotationStripLayerComponent, selector: "igx-data-annotation-strip-layer", inputs: { startValueMemberPath: "startValueMemberPath", startLabelMemberPath: "startLabelMemberPath", startLabelDisplayMode: "startLabelDisplayMode", endValueMemberPath: "endValueMemberPath", endLabelMemberPath: "endLabelMemberPath", endLabelDisplayMode: "endLabelDisplayMode", centerLabelMemberPath: "centerLabelMemberPath", centerLabelDisplayMode: "centerLabelDisplayMode" }, providers: [{ provide: IgxDataAnnotationRangeLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxDataAnnotationShapeLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxDataAnnotationAxisLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }], usesInheritance: true, ngImport: i0, template: ``, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxDataAnnotationStripLayerComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxDataAnnotationStripLayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-data-annotation-strip-layer',
                    template: ``,
                    providers: [{ provide: IgxDataAnnotationRangeLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxDataAnnotationShapeLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxDataAnnotationAxisLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxDataAnnotationStripLayerComponent) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { startValueMemberPath: [{
                type: Input
            }], startLabelMemberPath: [{
                type: Input
            }], startLabelDisplayMode: [{
                type: Input
            }], endValueMemberPath: [{
                type: Input
            }], endLabelMemberPath: [{
                type: Input
            }], endLabelDisplayMode: [{
                type: Input
            }], centerLabelMemberPath: [{
                type: Input
            }], centerLabelDisplayMode: [{
                type: Input
            }] } });
