import { Component, Input } from '@angular/core';
import { HorizontalAlignment_$type } from "igniteui-angular-core";
import { VerticalAlignment_$type } from "igniteui-angular-core";
import { Visibility_$type } from "igniteui-angular-core";
import { ValueAxisLabelLocation_$type } from "./ValueAxisLabelLocation";
import { AngleAxisLabelLocation_$type } from "./AngleAxisLabelLocation";
import { IgxDomainChartComponent } from "./igx-domain-chart-component";
import { brushToString, stringToBrush, ensureBool, ensureEnum, arrayFindByName } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents a base class for domain charts with X/Y axes
*/
export let IgxRadialBaseChartComponent = /*@__PURE__*/ (() => {
    class IgxRadialBaseChartComponent extends IgxDomainChartComponent {
        constructor() {
            super();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
        */
        get angleAxisFormatLabel() {
            return this.i.aau;
        }
        set angleAxisFormatLabel(v) {
            this.i.aau = v;
        }
        /**
         * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
        */
        get valueAxisFormatLabel() {
            return this.i.aav;
        }
        set valueAxisFormatLabel(v) {
            this.i.aav = v;
        }
        /**
         * Gets or sets the left margin of labels on the X-axis
        */
        get angleAxisLabelLeftMargin() {
            return this.i.ab9;
        }
        set angleAxisLabelLeftMargin(v) {
            this.i.ab9 = +v;
        }
        /**
         * Gets or sets the top margin of labels on the X-axis
        */
        get angleAxisLabelTopMargin() {
            return this.i.acb;
        }
        set angleAxisLabelTopMargin(v) {
            this.i.acb = +v;
        }
        /**
         * Gets or sets the right margin of labels on the X-axis
        */
        get angleAxisLabelRightMargin() {
            return this.i.aca;
        }
        set angleAxisLabelRightMargin(v) {
            this.i.aca = +v;
        }
        /**
         * Gets or sets the bottom margin of labels on the X-axis
        */
        get angleAxisLabelBottomMargin() {
            return this.i.ab8;
        }
        set angleAxisLabelBottomMargin(v) {
            this.i.ab8 = +v;
        }
        /**
         * Gets or sets the left margin of labels on the Y-axis
        */
        get valueAxisLabelLeftMargin() {
            return this.i.acw;
        }
        set valueAxisLabelLeftMargin(v) {
            this.i.acw = +v;
        }
        /**
         * Gets or sets the top margin of labels on the Y-axis
        */
        get valueAxisLabelTopMargin() {
            return this.i.acy;
        }
        set valueAxisLabelTopMargin(v) {
            this.i.acy = +v;
        }
        /**
         * Gets or sets the right margin of labels on the Y-axis
        */
        get valueAxisLabelRightMargin() {
            return this.i.acx;
        }
        set valueAxisLabelRightMargin(v) {
            this.i.acx = +v;
        }
        /**
         * Gets or sets the bottom margin of labels on the Y-axis
        */
        get valueAxisLabelBottomMargin() {
            return this.i.acv;
        }
        set valueAxisLabelBottomMargin(v) {
            this.i.acv = +v;
        }
        /**
         * Gets or sets color of labels on the X-axis
        */
        get angleAxisLabelTextColor() {
            return brushToString(this.i.ag9);
        }
        set angleAxisLabelTextColor(v) {
            this.i.ag9 = stringToBrush(v);
        }
        /**
         * Gets or sets color of labels on the Y-axis
        */
        get valueAxisLabelTextColor() {
            return brushToString(this.i.ahg);
        }
        set valueAxisLabelTextColor(v) {
            this.i.ahg = stringToBrush(v);
        }
        /**
         * Gets the actual color of labels on the X-axis
        */
        get actualAngleAxisLabelTextColor() {
            return brushToString(this.i.ag7);
        }
        set actualAngleAxisLabelTextColor(v) {
            this.i.ag7 = stringToBrush(v);
        }
        /**
         * Gets the actual color of labels on the Y-axis
        */
        get actualValueAxisLabelTextColor() {
            return brushToString(this.i.ag8);
        }
        set actualValueAxisLabelTextColor(v) {
            this.i.ag8 = stringToBrush(v);
        }
        /**
         * Gets or sets the margin around a title on the X-axis
        */
        get angleAxisTitleMargin() {
            return this.i.acm;
        }
        set angleAxisTitleMargin(v) {
            this.i.acm = +v;
        }
        /**
         * Gets or sets the margin around a title on the Y-axis
        */
        get valueAxisTitleMargin() {
            return this.i.ac9;
        }
        set valueAxisTitleMargin(v) {
            this.i.ac9 = +v;
        }
        /**
         * Gets or sets the left margin of a title on the X-axis
        */
        get angleAxisTitleLeftMargin() {
            return this.i.acl;
        }
        set angleAxisTitleLeftMargin(v) {
            this.i.acl = +v;
        }
        /**
         * Gets or sets the left margin of a title on the Y-axis
        */
        get valueAxisTitleLeftMargin() {
            return this.i.ac8;
        }
        set valueAxisTitleLeftMargin(v) {
            this.i.ac8 = +v;
        }
        /**
         * Gets or sets the top margin of a title on the X-axis
        */
        get angleAxisTitleTopMargin() {
            return this.i.aco;
        }
        set angleAxisTitleTopMargin(v) {
            this.i.aco = +v;
        }
        /**
         * Gets or sets the top margin of a title on the Y-axis
        */
        get valueAxisTitleTopMargin() {
            return this.i.adb;
        }
        set valueAxisTitleTopMargin(v) {
            this.i.adb = +v;
        }
        /**
         * Gets or sets the right margin of a title on the X-axis
        */
        get angleAxisTitleRightMargin() {
            return this.i.acn;
        }
        set angleAxisTitleRightMargin(v) {
            this.i.acn = +v;
        }
        /**
         * Gets or sets the right margin of a title on the Y-axis
        */
        get valueAxisTitleRightMargin() {
            return this.i.ada;
        }
        set valueAxisTitleRightMargin(v) {
            this.i.ada = +v;
        }
        /**
         * Gets or sets the bottom margin of a title on the X-axis
        */
        get angleAxisTitleBottomMargin() {
            return this.i.ack;
        }
        set angleAxisTitleBottomMargin(v) {
            this.i.ack = +v;
        }
        /**
         * Gets or sets the bottom margin of a title on the Y-axis
        */
        get valueAxisTitleBottomMargin() {
            return this.i.ac7;
        }
        set valueAxisTitleBottomMargin(v) {
            this.i.ac7 = +v;
        }
        /**
         * Gets or sets color of title on the X-axis
        */
        get angleAxisTitleTextColor() {
            return brushToString(this.i.ahf);
        }
        set angleAxisTitleTextColor(v) {
            this.i.ahf = stringToBrush(v);
        }
        /**
         * Gets or sets color of title on the Y-axis
        */
        get valueAxisTitleTextColor() {
            return brushToString(this.i.ahm);
        }
        set valueAxisTitleTextColor(v) {
            this.i.ahm = stringToBrush(v);
        }
        /**
         * Gets or sets CSS font property for labels on X-axis
        */
        get angleAxisLabelTextStyle() {
            return this.i.ad4;
        }
        set angleAxisLabelTextStyle(v) {
            this.i.ad4 = v;
        }
        /**
         * Gets or sets CSS font property for labels on Y-axis
        */
        get valueAxisLabelTextStyle() {
            return this.i.afc;
        }
        set valueAxisLabelTextStyle(v) {
            this.i.afc = v;
        }
        /**
         * Gets or sets CSS font property for title on X-axis
        */
        get angleAxisTitleTextStyle() {
            return this.i.aeu;
        }
        set angleAxisTitleTextStyle(v) {
            this.i.aeu = v;
        }
        /**
         * Gets or sets CSS font property for title on Y-axis
        */
        get valueAxisTitleTextStyle() {
            return this.i.af2;
        }
        set valueAxisTitleTextStyle(v) {
            this.i.af2 = v;
        }
        /**
         * Gets or sets the format for labels along the X-axis.
        */
        get angleAxisLabel() {
            return this.i.ade;
        }
        set angleAxisLabel(v) {
            this.i.ade = v;
        }
        /**
         * Gets or sets the property or string from which the labels are derived.
        */
        get valueAxisLabel() {
            return this.i.adf;
        }
        set valueAxisLabel(v) {
            this.i.adf = v;
        }
        /**
         * Gets or sets the color to apply to major gridlines along the X-axis.
        */
        get angleAxisMajorStroke() {
            return brushToString(this.i.aha);
        }
        set angleAxisMajorStroke(v) {
            this.i.aha = stringToBrush(v);
        }
        /**
         * Gets or sets the color to apply to major gridlines along the Y-axis.
        */
        get valueAxisMajorStroke() {
            return brushToString(this.i.ahh);
        }
        set valueAxisMajorStroke(v) {
            this.i.ahh = stringToBrush(v);
        }
        /**
         * Gets or sets the thickness to apply to major gridlines along the X-axis.
        */
        get angleAxisMajorStrokeThickness() {
            return this.i.acc;
        }
        set angleAxisMajorStrokeThickness(v) {
            this.i.acc = +v;
        }
        /**
         * Gets or sets the thickness to apply to major gridlines along the Y-axis.
        */
        get valueAxisMajorStrokeThickness() {
            return this.i.acz;
        }
        set valueAxisMajorStrokeThickness(v) {
            this.i.acz = +v;
        }
        /**
         * Gets or sets the thickness to apply to minor gridlines along the X-axis.
        */
        get angleAxisMinorStrokeThickness() {
            return this.i.acf;
        }
        set angleAxisMinorStrokeThickness(v) {
            this.i.acf = +v;
        }
        /**
         * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
        */
        get valueAxisMinorStrokeThickness() {
            return this.i.ac2;
        }
        set valueAxisMinorStrokeThickness(v) {
            this.i.ac2 = +v;
        }
        /**
         * Gets or sets the color to apply to stripes along the X-axis.
        */
        get angleAxisStrip() {
            return brushToString(this.i.ahc);
        }
        set angleAxisStrip(v) {
            this.i.ahc = stringToBrush(v);
        }
        /**
         * Gets or sets the color to apply to stripes along the Y-axis.
        */
        get valueAxisStrip() {
            return brushToString(this.i.ahj);
        }
        set valueAxisStrip(v) {
            this.i.ahj = stringToBrush(v);
        }
        /**
         * Gets or sets the color to apply to the X-axis line.
        */
        get angleAxisStroke() {
            return brushToString(this.i.ahd);
        }
        set angleAxisStroke(v) {
            this.i.ahd = stringToBrush(v);
        }
        /**
         * Gets or sets the color to apply to the Y-axis line.
        */
        get valueAxisStroke() {
            return brushToString(this.i.ahk);
        }
        set valueAxisStroke(v) {
            this.i.ahk = stringToBrush(v);
        }
        /**
         * Gets or sets the thickness to apply to the X-axis line.
        */
        get angleAxisStrokeThickness() {
            return this.i.acg;
        }
        set angleAxisStrokeThickness(v) {
            this.i.acg = +v;
        }
        /**
         * Gets or sets the thickness to apply to the Y-axis line.
        */
        get valueAxisStrokeThickness() {
            return this.i.ac3;
        }
        set valueAxisStrokeThickness(v) {
            this.i.ac3 = +v;
        }
        /**
         * Gets or sets the length of tickmarks along the X-axis.
        */
        get angleAxisTickLength() {
            return this.i.ach;
        }
        set angleAxisTickLength(v) {
            this.i.ach = +v;
        }
        /**
         * Gets or sets the length of tickmarks along the Y-axis.
        */
        get valueAxisTickLength() {
            return this.i.ac4;
        }
        set valueAxisTickLength(v) {
            this.i.ac4 = +v;
        }
        /**
         * Gets or sets the color to apply to tickmarks along the X-axis.
        */
        get angleAxisTickStroke() {
            return brushToString(this.i.ahe);
        }
        set angleAxisTickStroke(v) {
            this.i.ahe = stringToBrush(v);
        }
        /**
         * Gets or sets the color to apply to tickmarks along the Y-axis.
        */
        get valueAxisTickStroke() {
            return brushToString(this.i.ahl);
        }
        set valueAxisTickStroke(v) {
            this.i.ahl = stringToBrush(v);
        }
        /**
         * Gets or sets the thickness to apply to tickmarks along the X-axis.
        */
        get angleAxisTickStrokeThickness() {
            return this.i.aci;
        }
        set angleAxisTickStrokeThickness(v) {
            this.i.aci = +v;
        }
        /**
         * Gets or sets the thickness to apply to tickmarks along the Y-axis.
        */
        get valueAxisTickStrokeThickness() {
            return this.i.ac5;
        }
        set valueAxisTickStrokeThickness(v) {
            this.i.ac5 = +v;
        }
        /**
         * Gets or sets the Text to display below the X-axis.
        */
        get angleAxisTitle() {
            return this.i.ael;
        }
        set angleAxisTitle(v) {
            this.i.ael = v;
        }
        /**
         * Gets or sets the Text to display to the left of the Y-axis.
        */
        get valueAxisTitle() {
            return this.i.aft;
        }
        set valueAxisTitle(v) {
            this.i.aft = v;
        }
        /**
         * Gets or sets the color to apply to minor gridlines along the X-axis.
        */
        get angleAxisMinorStroke() {
            return brushToString(this.i.ahb);
        }
        set angleAxisMinorStroke(v) {
            this.i.ahb = stringToBrush(v);
        }
        /**
         * Gets or sets the color to apply to minor gridlines along the Y-axis.
        */
        get valueAxisMinorStroke() {
            return brushToString(this.i.ahi);
        }
        set valueAxisMinorStroke(v) {
            this.i.ahi = stringToBrush(v);
        }
        /**
         * Gets or sets the angle of rotation for labels along the X-axis.
        */
        get angleAxisLabelAngle() {
            return this.i.ab7;
        }
        set angleAxisLabelAngle(v) {
            this.i.ab7 = +v;
        }
        /**
         * Gets or sets the angle of rotation for labels along the Y-axis.
        */
        get valueAxisLabelAngle() {
            return this.i.acu;
        }
        set valueAxisLabelAngle(v) {
            this.i.acu = +v;
        }
        /**
         * Gets or sets the distance between the X-axis and the bottom of the chart.
        */
        get angleAxisExtent() {
            return this.i.ab6;
        }
        set angleAxisExtent(v) {
            this.i.ab6 = +v;
        }
        /**
         * Gets or sets the maximum distance between the X-axis and the bottom of the chart.
        */
        get angleAxisMaximumExtent() {
            return this.i.acd;
        }
        set angleAxisMaximumExtent(v) {
            this.i.acd = +v;
        }
        /**
         * Gets or sets the maximum width between the X-axis and the bottom of the chart, as a percentage of total chart width.
        */
        get angleAxisMaximumExtentPercentage() {
            return this.i.ace;
        }
        set angleAxisMaximumExtentPercentage(v) {
            this.i.ace = +v;
        }
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get valueAxisExtent() {
            return this.i.act;
        }
        set valueAxisExtent(v) {
            this.i.act = +v;
        }
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get valueAxisMaximumExtent() {
            return this.i.ac0;
        }
        set valueAxisMaximumExtent(v) {
            this.i.ac0 = +v;
        }
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get valueAxisMaximumExtentPercentage() {
            return this.i.ac1;
        }
        set valueAxisMaximumExtentPercentage(v) {
            this.i.ac1 = +v;
        }
        /**
         * Gets or sets the angle of rotation for the X-axis title.
        */
        get angleAxisTitleAngle() {
            return this.i.acj;
        }
        set angleAxisTitleAngle(v) {
            this.i.acj = +v;
        }
        /**
         * Gets or sets the angle of rotation for the Y-axis title.
        */
        get valueAxisTitleAngle() {
            return this.i.ac6;
        }
        set valueAxisTitleAngle(v) {
            this.i.ac6 = +v;
        }
        /**
         * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
        */
        get angleAxisInverted() {
            return this.i.aa2;
        }
        set angleAxisInverted(v) {
            this.i.aa2 = ensureBool(v);
        }
        /**
         * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
        */
        get valueAxisInverted() {
            return this.i.aa3;
        }
        set valueAxisInverted(v) {
            this.i.aa3 = ensureBool(v);
        }
        /**
         * Gets or sets Horizontal alignment of the X-axis title.
        */
        get angleAxisTitleAlignment() {
            return this.i.agp;
        }
        set angleAxisTitleAlignment(v) {
            this.i.agp = ensureEnum(HorizontalAlignment_$type, v);
        }
        /**
         * Gets or sets Vertical alignment of the Y-axis title.
        */
        get valueAxisTitleAlignment() {
            return this.i.ahs;
        }
        set valueAxisTitleAlignment(v) {
            this.i.ahs = ensureEnum(VerticalAlignment_$type, v);
        }
        /**
         * Gets or sets Horizontal alignment of X-axis labels.
        */
        get angleAxisLabelHorizontalAlignment() {
            return this.i.ago;
        }
        set angleAxisLabelHorizontalAlignment(v) {
            this.i.ago = ensureEnum(HorizontalAlignment_$type, v);
        }
        /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        */
        get valueAxisLabelHorizontalAlignment() {
            return this.i.agq;
        }
        set valueAxisLabelHorizontalAlignment(v) {
            this.i.agq = ensureEnum(HorizontalAlignment_$type, v);
        }
        /**
         * Gets or sets Vertical alignment of X-axis labels.
        */
        get angleAxisLabelVerticalAlignment() {
            return this.i.ahq;
        }
        set angleAxisLabelVerticalAlignment(v) {
            this.i.ahq = ensureEnum(VerticalAlignment_$type, v);
        }
        /**
         * Gets or sets Vertical alignment of Y-axis labels.
        */
        get valueAxisLabelVerticalAlignment() {
            return this.i.ahr;
        }
        set valueAxisLabelVerticalAlignment(v) {
            this.i.ahr = ensureEnum(VerticalAlignment_$type, v);
        }
        /**
         * Gets or sets Visibility of X-axis labels.
        */
        get angleAxisLabelVisibility() {
            return this.i.ahv;
        }
        set angleAxisLabelVisibility(v) {
            this.i.ahv = ensureEnum(Visibility_$type, v);
        }
        /**
         * Gets or sets Visibility of Y-axis labels.
        */
        get valueAxisLabelVisibility() {
            return this.i.ahw;
        }
        set valueAxisLabelVisibility(v) {
            this.i.ahw = ensureEnum(Visibility_$type, v);
        }
        /**
         * Gets or sets location of Y-axis labels, relative to the plot area.
        */
        get valueAxisLabelLocation() {
            return this.i.aaz;
        }
        set valueAxisLabelLocation(v) {
            this.i.aaz = ensureEnum(ValueAxisLabelLocation_$type, v);
        }
        /**
         * Gets or sets location of X-axis labels, relative to the plot area.
        */
        get angleAxisLabelLocation() {
            return this.i.aap;
        }
        set angleAxisLabelLocation(v) {
            this.i.aap = ensureEnum(AngleAxisLabelLocation_$type, v);
        }
        /**
         * Gets or sets the format string for the X axis label.
        */
        get angleAxisLabelFormat() {
            return this.i.adv;
        }
        set angleAxisLabelFormat(v) {
            this.i.adv = v;
        }
        /**
         * Gets or sets the format specifiers to use with the AngleAxisLabelFormat string.
        */
        get angleAxisLabelFormatSpecifiers() {
            return this.i.aam;
        }
        set angleAxisLabelFormatSpecifiers(v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                const re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.aam = v;
        }
        /**
         * Gets or sets the format string for the Y axis label.
        */
        get valueAxisLabelFormat() {
            return this.i.ae3;
        }
        set valueAxisLabelFormat(v) {
            this.i.ae3 = v;
        }
        /**
         * Gets or sets the format specifiers to use with the ValueAxisLabelFormat string.
        */
        get valueAxisLabelFormatSpecifiers() {
            return this.i.aan;
        }
        set valueAxisLabelFormatSpecifiers(v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                const re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.aan = v;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.angleAxisLabelFormatSpecifiers != null && arrayFindByName(this.angleAxisLabelFormatSpecifiers, name)) {
                return arrayFindByName(this.angleAxisLabelFormatSpecifiers, name);
            }
            if (this.valueAxisLabelFormatSpecifiers != null && arrayFindByName(this.valueAxisLabelFormatSpecifiers, name)) {
                return arrayFindByName(this.valueAxisLabelFormatSpecifiers, name);
            }
            return null;
        }
        /**
         * Called by the UI framework to provide a UI container for rendering this control.
        
        * @param container  * The UI container element.
        */
        provideContainer(container) {
            this.i.provideContainer(container);
        }
        /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
        getScaledAngle(unscaledValue) {
            let iv = this.i.acp(unscaledValue);
            return (iv);
        }
        /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
        getUnscaledAngle(scaledValue) {
            let iv = this.i.acr(scaledValue);
            return (iv);
        }
        /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
        getScaledValue(unscaledValue) {
            let iv = this.i.acq(unscaledValue);
            return (iv);
        }
        /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
        getUnscaledValue(scaledValue) {
            let iv = this.i.acs(scaledValue);
            return (iv);
        }
    }
    IgxRadialBaseChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxRadialBaseChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxRadialBaseChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxRadialBaseChartComponent, selector: "ng-component", inputs: { angleAxisFormatLabel: "angleAxisFormatLabel", valueAxisFormatLabel: "valueAxisFormatLabel", angleAxisLabelLeftMargin: "angleAxisLabelLeftMargin", angleAxisLabelTopMargin: "angleAxisLabelTopMargin", angleAxisLabelRightMargin: "angleAxisLabelRightMargin", angleAxisLabelBottomMargin: "angleAxisLabelBottomMargin", valueAxisLabelLeftMargin: "valueAxisLabelLeftMargin", valueAxisLabelTopMargin: "valueAxisLabelTopMargin", valueAxisLabelRightMargin: "valueAxisLabelRightMargin", valueAxisLabelBottomMargin: "valueAxisLabelBottomMargin", angleAxisLabelTextColor: "angleAxisLabelTextColor", valueAxisLabelTextColor: "valueAxisLabelTextColor", actualAngleAxisLabelTextColor: "actualAngleAxisLabelTextColor", actualValueAxisLabelTextColor: "actualValueAxisLabelTextColor", angleAxisTitleMargin: "angleAxisTitleMargin", valueAxisTitleMargin: "valueAxisTitleMargin", angleAxisTitleLeftMargin: "angleAxisTitleLeftMargin", valueAxisTitleLeftMargin: "valueAxisTitleLeftMargin", angleAxisTitleTopMargin: "angleAxisTitleTopMargin", valueAxisTitleTopMargin: "valueAxisTitleTopMargin", angleAxisTitleRightMargin: "angleAxisTitleRightMargin", valueAxisTitleRightMargin: "valueAxisTitleRightMargin", angleAxisTitleBottomMargin: "angleAxisTitleBottomMargin", valueAxisTitleBottomMargin: "valueAxisTitleBottomMargin", angleAxisTitleTextColor: "angleAxisTitleTextColor", valueAxisTitleTextColor: "valueAxisTitleTextColor", angleAxisLabelTextStyle: "angleAxisLabelTextStyle", valueAxisLabelTextStyle: "valueAxisLabelTextStyle", angleAxisTitleTextStyle: "angleAxisTitleTextStyle", valueAxisTitleTextStyle: "valueAxisTitleTextStyle", angleAxisLabel: "angleAxisLabel", valueAxisLabel: "valueAxisLabel", angleAxisMajorStroke: "angleAxisMajorStroke", valueAxisMajorStroke: "valueAxisMajorStroke", angleAxisMajorStrokeThickness: "angleAxisMajorStrokeThickness", valueAxisMajorStrokeThickness: "valueAxisMajorStrokeThickness", angleAxisMinorStrokeThickness: "angleAxisMinorStrokeThickness", valueAxisMinorStrokeThickness: "valueAxisMinorStrokeThickness", angleAxisStrip: "angleAxisStrip", valueAxisStrip: "valueAxisStrip", angleAxisStroke: "angleAxisStroke", valueAxisStroke: "valueAxisStroke", angleAxisStrokeThickness: "angleAxisStrokeThickness", valueAxisStrokeThickness: "valueAxisStrokeThickness", angleAxisTickLength: "angleAxisTickLength", valueAxisTickLength: "valueAxisTickLength", angleAxisTickStroke: "angleAxisTickStroke", valueAxisTickStroke: "valueAxisTickStroke", angleAxisTickStrokeThickness: "angleAxisTickStrokeThickness", valueAxisTickStrokeThickness: "valueAxisTickStrokeThickness", angleAxisTitle: "angleAxisTitle", valueAxisTitle: "valueAxisTitle", angleAxisMinorStroke: "angleAxisMinorStroke", valueAxisMinorStroke: "valueAxisMinorStroke", angleAxisLabelAngle: "angleAxisLabelAngle", valueAxisLabelAngle: "valueAxisLabelAngle", angleAxisExtent: "angleAxisExtent", angleAxisMaximumExtent: "angleAxisMaximumExtent", angleAxisMaximumExtentPercentage: "angleAxisMaximumExtentPercentage", valueAxisExtent: "valueAxisExtent", valueAxisMaximumExtent: "valueAxisMaximumExtent", valueAxisMaximumExtentPercentage: "valueAxisMaximumExtentPercentage", angleAxisTitleAngle: "angleAxisTitleAngle", valueAxisTitleAngle: "valueAxisTitleAngle", angleAxisInverted: "angleAxisInverted", valueAxisInverted: "valueAxisInverted", angleAxisTitleAlignment: "angleAxisTitleAlignment", valueAxisTitleAlignment: "valueAxisTitleAlignment", angleAxisLabelHorizontalAlignment: "angleAxisLabelHorizontalAlignment", valueAxisLabelHorizontalAlignment: "valueAxisLabelHorizontalAlignment", angleAxisLabelVerticalAlignment: "angleAxisLabelVerticalAlignment", valueAxisLabelVerticalAlignment: "valueAxisLabelVerticalAlignment", angleAxisLabelVisibility: "angleAxisLabelVisibility", valueAxisLabelVisibility: "valueAxisLabelVisibility", valueAxisLabelLocation: "valueAxisLabelLocation", angleAxisLabelLocation: "angleAxisLabelLocation", angleAxisLabelFormat: "angleAxisLabelFormat", angleAxisLabelFormatSpecifiers: "angleAxisLabelFormatSpecifiers", valueAxisLabelFormat: "valueAxisLabelFormat", valueAxisLabelFormatSpecifiers: "valueAxisLabelFormatSpecifiers" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
    return IgxRadialBaseChartComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxRadialBaseChartComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { angleAxisFormatLabel: [{
                type: Input
            }], valueAxisFormatLabel: [{
                type: Input
            }], angleAxisLabelLeftMargin: [{
                type: Input
            }], angleAxisLabelTopMargin: [{
                type: Input
            }], angleAxisLabelRightMargin: [{
                type: Input
            }], angleAxisLabelBottomMargin: [{
                type: Input
            }], valueAxisLabelLeftMargin: [{
                type: Input
            }], valueAxisLabelTopMargin: [{
                type: Input
            }], valueAxisLabelRightMargin: [{
                type: Input
            }], valueAxisLabelBottomMargin: [{
                type: Input
            }], angleAxisLabelTextColor: [{
                type: Input
            }], valueAxisLabelTextColor: [{
                type: Input
            }], actualAngleAxisLabelTextColor: [{
                type: Input
            }], actualValueAxisLabelTextColor: [{
                type: Input
            }], angleAxisTitleMargin: [{
                type: Input
            }], valueAxisTitleMargin: [{
                type: Input
            }], angleAxisTitleLeftMargin: [{
                type: Input
            }], valueAxisTitleLeftMargin: [{
                type: Input
            }], angleAxisTitleTopMargin: [{
                type: Input
            }], valueAxisTitleTopMargin: [{
                type: Input
            }], angleAxisTitleRightMargin: [{
                type: Input
            }], valueAxisTitleRightMargin: [{
                type: Input
            }], angleAxisTitleBottomMargin: [{
                type: Input
            }], valueAxisTitleBottomMargin: [{
                type: Input
            }], angleAxisTitleTextColor: [{
                type: Input
            }], valueAxisTitleTextColor: [{
                type: Input
            }], angleAxisLabelTextStyle: [{
                type: Input
            }], valueAxisLabelTextStyle: [{
                type: Input
            }], angleAxisTitleTextStyle: [{
                type: Input
            }], valueAxisTitleTextStyle: [{
                type: Input
            }], angleAxisLabel: [{
                type: Input
            }], valueAxisLabel: [{
                type: Input
            }], angleAxisMajorStroke: [{
                type: Input
            }], valueAxisMajorStroke: [{
                type: Input
            }], angleAxisMajorStrokeThickness: [{
                type: Input
            }], valueAxisMajorStrokeThickness: [{
                type: Input
            }], angleAxisMinorStrokeThickness: [{
                type: Input
            }], valueAxisMinorStrokeThickness: [{
                type: Input
            }], angleAxisStrip: [{
                type: Input
            }], valueAxisStrip: [{
                type: Input
            }], angleAxisStroke: [{
                type: Input
            }], valueAxisStroke: [{
                type: Input
            }], angleAxisStrokeThickness: [{
                type: Input
            }], valueAxisStrokeThickness: [{
                type: Input
            }], angleAxisTickLength: [{
                type: Input
            }], valueAxisTickLength: [{
                type: Input
            }], angleAxisTickStroke: [{
                type: Input
            }], valueAxisTickStroke: [{
                type: Input
            }], angleAxisTickStrokeThickness: [{
                type: Input
            }], valueAxisTickStrokeThickness: [{
                type: Input
            }], angleAxisTitle: [{
                type: Input
            }], valueAxisTitle: [{
                type: Input
            }], angleAxisMinorStroke: [{
                type: Input
            }], valueAxisMinorStroke: [{
                type: Input
            }], angleAxisLabelAngle: [{
                type: Input
            }], valueAxisLabelAngle: [{
                type: Input
            }], angleAxisExtent: [{
                type: Input
            }], angleAxisMaximumExtent: [{
                type: Input
            }], angleAxisMaximumExtentPercentage: [{
                type: Input
            }], valueAxisExtent: [{
                type: Input
            }], valueAxisMaximumExtent: [{
                type: Input
            }], valueAxisMaximumExtentPercentage: [{
                type: Input
            }], angleAxisTitleAngle: [{
                type: Input
            }], valueAxisTitleAngle: [{
                type: Input
            }], angleAxisInverted: [{
                type: Input
            }], valueAxisInverted: [{
                type: Input
            }], angleAxisTitleAlignment: [{
                type: Input
            }], valueAxisTitleAlignment: [{
                type: Input
            }], angleAxisLabelHorizontalAlignment: [{
                type: Input
            }], valueAxisLabelHorizontalAlignment: [{
                type: Input
            }], angleAxisLabelVerticalAlignment: [{
                type: Input
            }], valueAxisLabelVerticalAlignment: [{
                type: Input
            }], angleAxisLabelVisibility: [{
                type: Input
            }], valueAxisLabelVisibility: [{
                type: Input
            }], valueAxisLabelLocation: [{
                type: Input
            }], angleAxisLabelLocation: [{
                type: Input
            }], angleAxisLabelFormat: [{
                type: Input
            }], angleAxisLabelFormatSpecifiers: [{
                type: Input
            }], valueAxisLabelFormat: [{
                type: Input
            }], valueAxisLabelFormatSpecifiers: [{
                type: Input
            }] } });
