import { __extends } from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { DataAnnotationDisplayMode_$type } from "./DataAnnotationDisplayMode";
import { IgxDataAnnotationRangeLayerComponent } from "./igx-data-annotation-range-layer-component";
import { IgxDataAnnotationShapeLayerComponent } from "./igx-data-annotation-shape-layer-component";
import { IgxDataAnnotationAxisLayerComponent } from "./igx-data-annotation-axis-layer-component";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { DataAnnotationStripLayer } from "./DataAnnotationStripLayer";
import { ensureEnum } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents an annotation layer that renders vertical or horizontal strips between values mapped to these properties:
 * StartValueMemberPath
 * EndValueMemberPath
*/
var IgxDataAnnotationStripLayerComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgxDataAnnotationStripLayerComponent, _super);
    function IgxDataAnnotationStripLayerComponent() {
        return _super.call(this) || this;
    }
    IgxDataAnnotationStripLayerComponent.prototype.createImplementation = function () {
        return new DataAnnotationStripLayer();
    };
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "startValueMemberPath", {
        /**
         * Gets or sets name of data column with positions for the start of annotations.
        */
        get: function () {
            return this.i.ag3;
        },
        set: function (v) {
            this.i.ag3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "startLabelMemberPath", {
        /**
         * Gets or sets mapping custom label at the start of annotations.
        */
        get: function () {
            return this.i.ag0;
        },
        set: function (v) {
            this.i.ag0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "startLabelDisplayMode", {
        /**
         * Gets or sets display mode of label in the start annotation.
        */
        get: function () {
            return this.i.agc;
        },
        set: function (v) {
            this.i.agc = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "endValueMemberPath", {
        /**
         * Gets or sets name of data column with positions for end of annotation.
        */
        get: function () {
            return this.i.agw;
        },
        set: function (v) {
            this.i.agw = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "endLabelMemberPath", {
        /**
         * Gets or sets mapping custom label at the end of annotations.
        */
        get: function () {
            return this.i.agt;
        },
        set: function (v) {
            this.i.agt = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "endLabelDisplayMode", {
        /**
         * Gets or sets display mode of label at the end annotation.
        */
        get: function () {
            return this.i.agb;
        },
        set: function (v) {
            this.i.agb = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "centerLabelMemberPath", {
        /**
         * Gets or sets mapping custom label between start and end of data annotations.
        */
        get: function () {
            return this.i.agp;
        },
        set: function (v) {
            this.i.agp = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDataAnnotationStripLayerComponent.prototype, "centerLabelDisplayMode", {
        /**
         * Gets or sets display mode of label in the center annotation.
        */
        get: function () {
            return this.i.aga;
        },
        set: function (v) {
            this.i.aga = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgxDataAnnotationStripLayerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxDataAnnotationStripLayerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxDataAnnotationStripLayerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxDataAnnotationStripLayerComponent, selector: "igx-data-annotation-strip-layer", inputs: { startValueMemberPath: "startValueMemberPath", startLabelMemberPath: "startLabelMemberPath", startLabelDisplayMode: "startLabelDisplayMode", endValueMemberPath: "endValueMemberPath", endLabelMemberPath: "endLabelMemberPath", endLabelDisplayMode: "endLabelDisplayMode", centerLabelMemberPath: "centerLabelMemberPath", centerLabelDisplayMode: "centerLabelDisplayMode" }, providers: [{ provide: IgxDataAnnotationRangeLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxDataAnnotationShapeLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxDataAnnotationAxisLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }], usesInheritance: true, ngImport: i0, template: "", isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxDataAnnotationStripLayerComponent;
}(IgxDataAnnotationRangeLayerComponent));
export { IgxDataAnnotationStripLayerComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxDataAnnotationStripLayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-data-annotation-strip-layer',
                    template: "",
                    providers: [{ provide: IgxDataAnnotationRangeLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxDataAnnotationShapeLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxDataAnnotationAxisLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxDataAnnotationStripLayerComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { startValueMemberPath: [{
                type: Input
            }], startLabelMemberPath: [{
                type: Input
            }], startLabelDisplayMode: [{
                type: Input
            }], endValueMemberPath: [{
                type: Input
            }], endLabelMemberPath: [{
                type: Input
            }], endLabelDisplayMode: [{
                type: Input
            }], centerLabelMemberPath: [{
                type: Input
            }], centerLabelDisplayMode: [{
                type: Input
            }] } });
