import { DataAnnotationDisplayMode } from "./DataAnnotationDisplayMode";
import { AnnotationAppearanceMode } from "./AnnotationAppearanceMode";
import { IgxAxisComponent } from "./igx-axis-component";
import { DataAnnotationTargetMode } from "./DataAnnotationTargetMode";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { DataAnnotationAxisLayer } from "./DataAnnotationAxisLayer";
import * as i0 from "@angular/core";
/**
 * Represents a base annotation layer that displays annotations over an axis.
*/
export declare abstract class IgxDataAnnotationAxisLayerComponent extends IgxAnnotationLayerComponent {
    /**
                                 * @hidden
                                 */
    get i(): DataAnnotationAxisLayer;
    constructor();
    /**
     * Gets or sets display mode of label on axis annotation.
    */
    get annotationLabelDisplayMode(): DataAnnotationDisplayMode;
    set annotationLabelDisplayMode(v: DataAnnotationDisplayMode);
    static ngAcceptInputType_annotationLabelDisplayMode: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets whether to show all annotations over target axis
    */
    get annotationLabelVisible(): boolean;
    set annotationLabelVisible(v: boolean);
    static ngAcceptInputType_annotationLabelVisible: boolean | string;
    /**
     * Gets or sets the text color used in the axis annotation.
    */
    get annotationTextColor(): string;
    set annotationTextColor(v: string);
    /**
     * Gets or sets the mode used for shifting the text color in axis annotation.
    */
    get annotationTextColorMode(): AnnotationAppearanceMode;
    set annotationTextColorMode(v: AnnotationAppearanceMode);
    static ngAcceptInputType_annotationTextColorMode: AnnotationAppearanceMode | string;
    /**
     * Gets or sets the percentage used to shift AnnotationTextColor. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get annotationTextColorShift(): number;
    set annotationTextColorShift(v: number);
    static ngAcceptInputType_annotationTextColorShift: number | string;
    /**
     * Gets or sets whether the annotation text color matches brush of the layer
    */
    get annotationTextColorMatchLayer(): boolean;
    set annotationTextColorMatchLayer(v: boolean);
    static ngAcceptInputType_annotationTextColorMatchLayer: boolean | string;
    /**
     * Gets or sets the color used for backing of the axis annotation.
    */
    get annotationBackground(): string;
    set annotationBackground(v: string);
    /**
     * Gets or sets the border radius used for displaying the axis annotation.
    */
    get annotationBorderRadius(): number;
    set annotationBorderRadius(v: number);
    static ngAcceptInputType_annotationBorderRadius: number | string;
    /**
     * Gets or sets the mode used for shifting the background of axis annotation.
    */
    get annotationBackgroundMode(): AnnotationAppearanceMode;
    set annotationBackgroundMode(v: AnnotationAppearanceMode);
    static ngAcceptInputType_annotationBackgroundMode: AnnotationAppearanceMode | string;
    /**
     * Gets or sets the percentage used to shift AnnotationBackground. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get annotationBackgroundShift(): number;
    set annotationBackgroundShift(v: number);
    static ngAcceptInputType_annotationBackgroundShift: number | string;
    /**
     * Gets or sets whether the annotation background matches brush of the layer
    */
    get annotationBackgroundMatchLayer(): boolean;
    set annotationBackgroundMatchLayer(v: boolean);
    static ngAcceptInputType_annotationBackgroundMatchLayer: boolean | string;
    /**
     * Gets or sets whether the annotation border matches outline of the layer (if it has a fill visual) otherwise brush of the layer
    */
    get annotationBorderMatchLayer(): boolean;
    set annotationBorderMatchLayer(v: boolean);
    static ngAcceptInputType_annotationBorderMatchLayer: boolean | string;
    /**
     * Gets or sets the color used for border color of the axis annotation.
    */
    get annotationBorderColor(): string;
    set annotationBorderColor(v: string);
    /**
     * Gets or sets the mode used for shifting border color of the axis annotation.
    */
    get annotationBorderMode(): AnnotationAppearanceMode;
    set annotationBorderMode(v: AnnotationAppearanceMode);
    static ngAcceptInputType_annotationBorderMode: AnnotationAppearanceMode | string;
    /**
     * Gets or sets the percentage amount used to shift AnnotationBorderColor. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get annotationBorderShift(): number;
    set annotationBorderShift(v: number);
    static ngAcceptInputType_annotationBorderShift: number | string;
    get annotationPaddingBottom(): number;
    set annotationPaddingBottom(v: number);
    static ngAcceptInputType_annotationPaddingBottom: number | string;
    get annotationPaddingLeft(): number;
    set annotationPaddingLeft(v: number);
    static ngAcceptInputType_annotationPaddingLeft: number | string;
    get annotationPaddingRight(): number;
    set annotationPaddingRight(v: number);
    static ngAcceptInputType_annotationPaddingRight: number | string;
    get annotationPaddingTop(): number;
    set annotationPaddingTop(v: number);
    static ngAcceptInputType_annotationPaddingTop: number | string;
    ensureAnnotationPadding(): void;
    /**
     * Gets or sets border thickness of the axis annotations.
    */
    get annotationBorderThickness(): number;
    set annotationBorderThickness(v: number);
    static ngAcceptInputType_annotationBorderThickness: number | string;
    /**
     * Gets or sets maximum precision for displaying values on axis annotation.
    */
    get annotationValueMaxPrecision(): number;
    set annotationValueMaxPrecision(v: number);
    static ngAcceptInputType_annotationValueMaxPrecision: number | string;
    /**
     * Gets or sets minimum precision for displaying values on axis annotation.
    */
    get annotationValueMinPrecision(): number;
    set annotationValueMinPrecision(v: number);
    static ngAcceptInputType_annotationValueMinPrecision: number | string;
    /**
     * Gets or sets the target axis for this annotation. If null, this annotation will use TargetMode to determine target axis.
    */
    get targetAxis(): IgxAxisComponent;
    set targetAxis(v: IgxAxisComponent);
    /**
     * Gets or sets the mode for targeting axes present in the chart. Defaults to targeting all category-axes present in the chart
    */
    get targetMode(): DataAnnotationTargetMode;
    set targetMode(v: DataAnnotationTargetMode);
    static ngAcceptInputType_targetMode: DataAnnotationTargetMode | string;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxDataAnnotationAxisLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxDataAnnotationAxisLayerComponent, "ng-component", never, { "annotationLabelDisplayMode": "annotationLabelDisplayMode"; "annotationLabelVisible": "annotationLabelVisible"; "annotationTextColor": "annotationTextColor"; "annotationTextColorMode": "annotationTextColorMode"; "annotationTextColorShift": "annotationTextColorShift"; "annotationTextColorMatchLayer": "annotationTextColorMatchLayer"; "annotationBackground": "annotationBackground"; "annotationBorderRadius": "annotationBorderRadius"; "annotationBackgroundMode": "annotationBackgroundMode"; "annotationBackgroundShift": "annotationBackgroundShift"; "annotationBackgroundMatchLayer": "annotationBackgroundMatchLayer"; "annotationBorderMatchLayer": "annotationBorderMatchLayer"; "annotationBorderColor": "annotationBorderColor"; "annotationBorderMode": "annotationBorderMode"; "annotationBorderShift": "annotationBorderShift"; "annotationPaddingBottom": "annotationPaddingBottom"; "annotationPaddingLeft": "annotationPaddingLeft"; "annotationPaddingRight": "annotationPaddingRight"; "annotationPaddingTop": "annotationPaddingTop"; "annotationBorderThickness": "annotationBorderThickness"; "annotationValueMaxPrecision": "annotationValueMaxPrecision"; "annotationValueMinPrecision": "annotationValueMinPrecision"; "targetAxis": "targetAxis"; "targetMode": "targetMode"; }, {}, never, never>;
}
