import { EventEmitter } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { OverlayTextLocation } from "./OverlayTextLocation";
import { AnnotationAppearanceMode } from "./AnnotationAppearanceMode";
import { IgxOverlayTextUpdatingEventArgs } from "./igx-overlay-text-updating-event-args";
import { IgxDataAnnotationItem } from "./igx-data-annotation-item";
import { IgxDataAnnotationInfo } from "./igx-data-annotation-info";
import { IgxDataAnnotationAxisLayerComponent } from "./igx-data-annotation-axis-layer-component";
import { DataAnnotationShapeLayer } from "./DataAnnotationShapeLayer";
import * as i0 from "@angular/core";
/**
 * Represents a base annotation layer that renders shapes defined by derived data annotation, e.g. line, strip, slice, rect, band
*/
export declare abstract class IgxDataAnnotationShapeLayerComponent extends IgxDataAnnotationAxisLayerComponent {
    /**
                                 * @hidden
                                 */
    get i(): DataAnnotationShapeLayer;
    constructor();
    /**
     * Gets or sets whether to draw shape of annotations in the plot area
    */
    get annotationShapeVisible(): boolean;
    set annotationShapeVisible(v: boolean);
    static ngAcceptInputType_annotationShapeVisible: boolean | string;
    /**
     * Gets or sets whether the data items of the annotations use world coordinates (0.0 - 1.0) or they default to using axes coordinates (data indexes for category axis or data values for numeric axis).
    */
    get itemsUseWorldCoordinates(): boolean;
    set itemsUseWorldCoordinates(v: boolean);
    static ngAcceptInputType_itemsUseWorldCoordinates: boolean | string;
    /**
     * Gets or sets location of the overlay text in relation to shape of data annotation.
    */
    get overlayTextLocation(): OverlayTextLocation;
    set overlayTextLocation(v: OverlayTextLocation);
    static ngAcceptInputType_overlayTextLocation: OverlayTextLocation | string;
    /**
     * Gets or sets the horizontal margin of the overlay text in relation to shape of data annotation.
    */
    get overlayTextHorizontalMargin(): number;
    set overlayTextHorizontalMargin(v: number);
    static ngAcceptInputType_overlayTextHorizontalMargin: number | string;
    /**
     * Gets or sets the vertical margin of the overlay text in relation to shape of data annotation.
    */
    get overlayTextVerticalMargin(): number;
    set overlayTextVerticalMargin(v: number);
    static ngAcceptInputType_overlayTextVerticalMargin: number | string;
    /**
     * Gets or sets the horizontal padding of the overlay text in relation to shape of data annotation.
    */
    get overlayTextHorizontalPadding(): number;
    set overlayTextHorizontalPadding(v: number);
    static ngAcceptInputType_overlayTextHorizontalPadding: number | string;
    /**
     * Gets or sets the vertical padding of the overlay text in relation to shape of data annotation.
    */
    get overlayTextVerticalPadding(): number;
    set overlayTextVerticalPadding(v: number);
    static ngAcceptInputType_overlayTextVerticalPadding: number | string;
    /**
     * Gets or sets the angle rotation (in degrees) of the overlay text in relation to shape of data annotation.
    */
    get overlayTextAngle(): number;
    set overlayTextAngle(v: number);
    static ngAcceptInputType_overlayTextAngle: number | string;
    /**
     * Gets or sets the color the overlay text.
    */
    get overlayTextColor(): string;
    set overlayTextColor(v: string);
    /**
     * Gets or sets the background the overlay text.
    */
    get overlayTextBackground(): string;
    set overlayTextBackground(v: string);
    /**
     * Gets or sets the border stroke of the overlay text.
    */
    get overlayTextBorderColor(): string;
    set overlayTextBorderColor(v: string);
    /**
     * Gets or sets the border corner of the overlay text.
    */
    get overlayTextBorderRadius(): number;
    set overlayTextBorderRadius(v: number);
    static ngAcceptInputType_overlayTextBorderRadius: number | string;
    /**
     * Gets or sets the border thickness of the overlay text.
    */
    get overlayTextBorderThickness(): number;
    set overlayTextBorderThickness(v: number);
    static ngAcceptInputType_overlayTextBorderThickness: number | string;
    /**
     * Gets or sets whether the overlay text is visible in shape of data annotation
    */
    get overlayTextVisible(): boolean;
    set overlayTextVisible(v: boolean);
    static ngAcceptInputType_overlayTextVisible: boolean | string;
    /**
     * Gets or sets name of data column with text that will be displayed as overlay text.
    */
    get overlayTextMemberPath(): string;
    set overlayTextMemberPath(v: string);
    /**
     * Gets or sets the text that will be displayed as the overlay annotation.
    */
    get overlayText(): string;
    set overlayText(v: string);
    /**
     * Gets or sets the shift of the overlay text color based on OverlayTextColorMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get overlayTextColorShift(): number;
    set overlayTextColorShift(v: number);
    static ngAcceptInputType_overlayTextColorShift: number | string;
    /**
     * Gets or sets the mode used for shifting the background of overlay text based on the target series.
    */
    get overlayTextColorMode(): AnnotationAppearanceMode;
    set overlayTextColorMode(v: AnnotationAppearanceMode);
    static ngAcceptInputType_overlayTextColorMode: AnnotationAppearanceMode | string;
    /**
     * Gets or sets whether the overlay text color matches brush of the layer
    */
    get overlayTextColorMatchLayer(): boolean;
    set overlayTextColorMatchLayer(v: boolean);
    static ngAcceptInputType_overlayTextColorMatchLayer: boolean | string;
    /**
     * Gets or sets the shift of the overlay background based on OverlayTextBackgroundMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get overlayTextBackgroundShift(): number;
    set overlayTextBackgroundShift(v: number);
    static ngAcceptInputType_overlayTextBackgroundShift: number | string;
    /**
     * Gets or sets the mode used for shifting the background of overlay text based on the target series.
    */
    get overlayTextBackgroundMode(): AnnotationAppearanceMode;
    set overlayTextBackgroundMode(v: AnnotationAppearanceMode);
    static ngAcceptInputType_overlayTextBackgroundMode: AnnotationAppearanceMode | string;
    /**
     * Gets or sets whether the overlay text background matches brush of the layer
    */
    get overlayTextBackgroundMatchLayer(): boolean;
    set overlayTextBackgroundMatchLayer(v: boolean);
    static ngAcceptInputType_overlayTextBackgroundMatchLayer: boolean | string;
    /**
     * Gets or sets the shift of the overlay border based on OverlayTextBorderMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get overlayTextBorderShift(): number;
    set overlayTextBorderShift(v: number);
    static ngAcceptInputType_overlayTextBorderShift: number | string;
    /**
     * Gets or sets the mode used for shifting the border of overlay text based on the target series.
    */
    get overlayTextBorderMode(): AnnotationAppearanceMode;
    set overlayTextBorderMode(v: AnnotationAppearanceMode);
    static ngAcceptInputType_overlayTextBorderMode: AnnotationAppearanceMode | string;
    /**
     * Gets or sets whether the overlay text border matches brush of the layer
    */
    get overlayTextBorderMatchLayer(): boolean;
    set overlayTextBorderMatchLayer(v: boolean);
    static ngAcceptInputType_overlayTextBorderMatchLayer: boolean | string;
    /**
     * Gets or Sets the style to use for the display text.
    */
    get overlayTextStyle(): string;
    set overlayTextStyle(v: string);
    /**
     * Gets whether the annotation layer is currently targeting horizontal axis.
    */
    get isTargetingHorizontalAxis(): boolean;
    set isTargetingHorizontalAxis(v: boolean);
    static ngAcceptInputType_isTargetingHorizontalAxis: boolean | string;
    /**
     * Converts world coordinate (0.0 - 1.0) to pixel coordinate that is relative to component's size
    
    */
    fromWorld(world: IgPoint): IgPoint;
    /**
     * Converts world X coordinate (0.0 - 1.0) to pixel coordinate that is relative to component's width
    
    */
    fromWorldX(x: number): number;
    /**
     * Converts world Y coordinate (0.0 - 1.0) to pixel coordinate that is relative to component's height
    
    */
    fromWorldY(y: number): number;
    /**
     * Converts pixel coordinate (relative to component's size) to world coordinate (0.0 - 1.0)
    
    */
    toWorld(pixel: IgPoint): IgPoint;
    /**
     * Converts pixel X coordinate (relative to component's width) to world coordinate (0.0 - 1.0)
    
    */
    toWorldX(x: number): number;
    /**
     * Converts pixel Y coordinate (relative to component's height) to world coordinate (0.0 - 1.0)
    
    */
    toWorldY(y: number): number;
    private _stylingOverlayText;
    /**
     * Event raised when updating style of overlay text
    */
    get stylingOverlayText(): EventEmitter<{
        sender: any;
        args: IgxOverlayTextUpdatingEventArgs;
    }>;
    private _stylingShapeAnnotation;
    /**
     * Event raised when updating style of annotation
    */
    get stylingShapeAnnotation(): EventEmitter<{
        sender: any;
        args: IgxDataAnnotationItem;
    }>;
    private _stylingAxisAnnotation;
    /**
     * Event raised when updating style of annotation
    */
    get stylingAxisAnnotation(): EventEmitter<{
        sender: any;
        args: IgxDataAnnotationInfo;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxDataAnnotationShapeLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxDataAnnotationShapeLayerComponent, "ng-component", never, { "annotationShapeVisible": "annotationShapeVisible"; "itemsUseWorldCoordinates": "itemsUseWorldCoordinates"; "overlayTextLocation": "overlayTextLocation"; "overlayTextHorizontalMargin": "overlayTextHorizontalMargin"; "overlayTextVerticalMargin": "overlayTextVerticalMargin"; "overlayTextHorizontalPadding": "overlayTextHorizontalPadding"; "overlayTextVerticalPadding": "overlayTextVerticalPadding"; "overlayTextAngle": "overlayTextAngle"; "overlayTextColor": "overlayTextColor"; "overlayTextBackground": "overlayTextBackground"; "overlayTextBorderColor": "overlayTextBorderColor"; "overlayTextBorderRadius": "overlayTextBorderRadius"; "overlayTextBorderThickness": "overlayTextBorderThickness"; "overlayTextVisible": "overlayTextVisible"; "overlayTextMemberPath": "overlayTextMemberPath"; "overlayText": "overlayText"; "overlayTextColorShift": "overlayTextColorShift"; "overlayTextColorMode": "overlayTextColorMode"; "overlayTextColorMatchLayer": "overlayTextColorMatchLayer"; "overlayTextBackgroundShift": "overlayTextBackgroundShift"; "overlayTextBackgroundMode": "overlayTextBackgroundMode"; "overlayTextBackgroundMatchLayer": "overlayTextBackgroundMatchLayer"; "overlayTextBorderShift": "overlayTextBorderShift"; "overlayTextBorderMode": "overlayTextBorderMode"; "overlayTextBorderMatchLayer": "overlayTextBorderMatchLayer"; "overlayTextStyle": "overlayTextStyle"; "isTargetingHorizontalAxis": "isTargetingHorizontalAxis"; }, { "stylingOverlayText": "stylingOverlayText"; "stylingShapeAnnotation": "stylingShapeAnnotation"; "stylingAxisAnnotation": "stylingAxisAnnotation"; }, never, never>;
}
